FAQ — Daarmaan 0.2.1 documentation

### Navigation

- index
- previous |
- Daarmaan 0.2.1 documentation »

# FAQ

## 1. What is Daarmaan ?

Daarmaan is Server/client SSO service.

## 2. What does Daarmaan means ?

Daarmaan is the name of an ancient warrior in Persian history that was the guardian of Persepolice.

## 3. Can use Daarmaan with other languages ?

Of course. But your have to write your client by your self. your client should send an amp packet. But I’m currently working on a ruby implementation.

### Navigation

- index
- previous |
- Daarmaan 0.2.1 documentation »